aboutsummaryrefslogtreecommitdiffstats
path: root/src/EncoderList.hxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/EncoderList.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/EncoderList.hxx b/src/EncoderList.hxx
index feaf7a6d1..8cbb389a4 100644
--- a/src/EncoderList.hxx
+++ b/src/EncoderList.hxx
@@ -27,14 +27,14 @@ extern const EncoderPlugin *const encoder_plugins[];
#define encoder_plugins_for_each(plugin) \
for (const EncoderPlugin *plugin, \
*const*encoder_plugin_iterator = &encoder_plugins[0]; \
- (plugin = *encoder_plugin_iterator) != NULL; \
+ (plugin = *encoder_plugin_iterator) != nullptr; \
++encoder_plugin_iterator)
/**
* Looks up an encoder plugin by its name.
*
* @param name the encoder name to look for
* @return the encoder plugin with the specified name, or NULL if none
* was found
*/
const EncoderPlugin *
@@ -27,14 +27,14 @@ extern const EncoderPlugin *const encoder_plugins[];
*
* @param name the encoder name to look for
- * @return the encoder plugin with the specified name, or NULL if none
+ * @return the encoder plugin with the specified name, or nullptr if none
* was found
*/